@@ -6,8 +6,9 @@ use 5.016;
 use warnings;
 use utf8;
 
-our $VERSION = 0.006;
+our $VERSION = 0.007;
 
+use IP::Geolocation::MMDB::Metadata;
 use Math::BigInt 1.999807;
 
 require XSLoader;
@@ -40,6 +41,12 @@ sub getcc {
   return $country_code;
 }
 
+sub metadata {
+  my ($self) = @_;
+
+  return IP::Geolocation::MMDB::Metadata->new(%{$self->_metadata});
+}
+
 ## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 
 sub _to_bigint {
@@ -59,12 +66,13 @@ IP::Geolocation::MMDB - Read MaxMind DB files
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
   use IP::Geolocation::MMDB;
   my $db = IP::Geolocation::MMDB->new(file => 'GeoIP2-Country.mmdb');
+  my $metadata = $db->metadata;
   my $lookup_result = $db->record_for_address('1.2.3.4');
   my $country_code = $db->getcc('2620:fe::9');
 
@@ -96,6 +104,15 @@ Takes an IPv4 or IPv6 address as a string and returns the data associated with
 the IP address or the undefined value.  Dies if the address is not a valid IP
 address.
 
+The returned data is usually a hash reference but could also be a an array
+reference or a scalar for custom databases.
+
+=head2 metadata
+
+  my $metadata = $db->metadata;
+
+Returns an L<IP::Geolocation::MMDB::Metadata> object for the database.
+
 =head2 version
 
   my $version = IP::Geolocation::MMDB->version;
@@ -123,6 +140,10 @@ A database error occurred while looking up an IP address.
 A database error occurred while reading the data associated with an IP
 address.
 
+=item B<< Couldn't read metadata >>
+
+An error occurred while reading the database's metadata.
+
 =back
 
 =head1 CONFIGURATION AND ENVIRONMENT
